@@ -14,9 +14,7 @@ file.glob = require('glob');
 file.minimatch = require('minimatch');
 file.findup = require('findup-sync');
 var YAML = require('js-yaml');
-var rimraf = require('rimraf');
 var iconv = require('iconv-lite');
-var mkdirp = require('mkdirp').sync;
 
 // Windows?
 var win32 = process.platform === 'win32';
@@ -181,7 +179,7 @@ file.expandMapping = function(patterns, destBase, options) {
 file.mkdir = function(dirpath, mode) {
   if (grunt.option('no-write')) { return; }
   try {
-    mkdirp(dirpath, { mode: mode });
+    fs.mkdirSync(dirpath, { recursive: true, mode: mode });
   } catch (e) {
     throw grunt.util.error('Unable to create directory "' + dirpath + '" (Error code: ' + e.code + ').', e);
   }
@@ -373,7 +371,7 @@ file.delete = function(filepath, options) {
   try {
     // Actually delete. Or not.
     if (!nowrite) {
-      rimraf.sync(filepath);
+      fs.rmSync(filepath, { recursive: true, force: true });
     }
     grunt.verbose.ok();
     return true;
